---
title: <span class="badge builder"></span> StackableFieldConfig
---
# <span class="badge builder"></span> StackableFieldConfig

## Constructor

```python
StackableFieldConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.StackableFieldConfig
```

### <span class="badge object-method"></span> stacking

```python
def stacking(stacking: cogbuilder.Builder[common.StackingConfig]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [StackableFieldConfig](./object-StackableFieldConfig.md)
